@@ -1,10 +1,9 @@
-# Copyright (c) 2011-2012, Mark Peek <mark@peek.org>
+# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
 # All rights reserved.
 #
 # See LICENSE file for full license.
 
-import json
-from . import AWSHelperFn, AWSObject
+from . import AWSHelperFn, AWSObject, AWSProperty
 
 
 class Element(AWSHelperFn):
@@ -18,16 +17,12 @@ class Element(AWSHelperFn):
         return self.data
 
 
-class PrimaryKey(AWSObject):
+class PrimaryKey(AWSProperty):
     props = {
         'HashKeyElement': (Element, True),
         'RangeKeyElement': (Element, False),
     }
 
-    def __init__(self, **kwargs):
-        sup = super(PrimaryKey, self)
-        sup.__init__(None, props=self.props, **kwargs)
-
 
 class ProvisionedThroughput(AWSHelperFn):
     def __init__(self, ReadCapacityUnits, WriteCapacityUnits):
