@@ -1,10 +1,8 @@
-# Copyright (c) 2011-2012, Mark Peek <mark@peek.org>
+# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
 # All rights reserved.
 #
 # See LICENSE file for full license.
 
-import json
-
 from . import AWSHelperFn, AWSObject, AWSProperty, Ref
 
 
@@ -132,27 +130,19 @@ class NetworkAcl(AWSObject):
         sup.__init__(name, self.type, "Properties", self.props, **kwargs)
 
 
-class ICMP(AWSObject):
+class ICMP(AWSProperty):
     props = {
         'Code': (int, False),
         'Type': (int, False),
     }
 
-    def __init__(self, **kwargs):
-        sup = super(ICMP, self)
-        sup.__init__(None, None, "ICMP", self.props, **kwargs)
 
-
-class PortRange(AWSObject):
+class PortRange(AWSProperty):
     props = {
         'From': (int, False),
         'To': (int, False),
     }
 
-    def __init__(self, **kwargs):
-        sup = super(PortRange, self)
-        sup.__init__(None, None, "PortRange", self.props, **kwargs)
-
 
 class NetworkAclEntry(AWSObject):
     props = {
@@ -250,7 +240,7 @@ class SecurityGroupIngress(AWSObject):
         sup.__init__(name, self.type, "Properties", self.props, **kwargs)
 
 
-class SecurityGroupRule(AWSObject):
+class SecurityGroupRule(AWSProperty):
     props = {
         'IpProtocol': (basestring, True),
         'CidrIp': (basestring, False),
@@ -261,10 +251,6 @@ class SecurityGroupRule(AWSObject):
         'ToPort': (basestring, True),
     }
 
-    def __init__(self, **kwargs):
-        sup = super(SecurityGroupRule, self)
-        sup.__init__(None, props=self.props, **kwargs)
-
 
 class SecurityGroup(AWSObject):
     props = {
