@@ -1,10 +1,9 @@
-# Copyright (c) 2011-2012, Mark Peek <mark@peek.org>
+# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
 # All rights reserved.
 #
 # See LICENSE file for full license.
 
-import json
-from . import AWSHelperFn, AWSObject
+from . import AWSObject
 
 
 class Domain(AWSObject):
