@@ -1,22 +1,17 @@
-# Copyright (c) 2011-2012, Mark Peek <mark@peek.org>
+# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
 # All rights reserved.
 #
 # See LICENSE file for full license.
 
-import json
-from . import AWSHelperFn, AWSObject
+from . import AWSObject, AWSProperty
 
 
-class Subscription(AWSObject):
+class Subscription(AWSProperty):
     props = {
         'Endpoint': (basestring, True),
         'Protocol': (basestring, True),
     }
 
-    def __init__(self, **kwargs):
-        sup = super(Subscription, self)
-        sup.__init__(None, props=self.props, **kwargs)
-
 
 class TopicPolicy(AWSObject):
     props = {
